
.. _gsi:
.. _sdf:

OpenOffice.org GSI/SDF format
*****************************

OpenOffice.org uses an internal format called SDF to manage localisation text.
The toolkit can successfully manage all features of this format converting it
to XLIFF or PO format with the :doc:`oo2po </commands/oo2po>` and oo2xliff
tools.

.. _gsi#features:

Features
========

* Handles all translatable text from the SDF
* Can also use 'x-comments' 'language' found in the SDF to provide translator
  comments
